pub struct Generation(pub u64);Expand description
Monotonic version of an account’s compiled policy snapshot. A snapshot with a generation older than the newest one an instance has seen is stale and must not be (re-)installed.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for Generation
impl Clone for Generation
impl Copy for Generation
Sourceimpl Debug for Generation
impl Debug for Generation
Sourceimpl<'de> Deserialize<'de> for Generation
impl<'de> Deserialize<'de> for Generation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for Generation
impl Display for Generation
impl Eq for Generation
Sourceimpl Hash for Generation
impl Hash for Generation
Sourceimpl Ord for Generation
impl Ord for Generation
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for Generation
impl PartialEq for Generation
Sourceimpl PartialOrd for Generation
impl PartialOrd for Generation
Sourceimpl Serialize for Generation
impl Serialize for Generation
impl StructuralPartialEq for Generation